===========
Change logs
===========

v0.1.2
======

:Date: 2024-11-04 (JST)

Fixes
-----

* Remove duplicated linebreak nodes.

v0.1.1
======

:Date: 2024-11-04 (JST)

Fixes
-----

* Work for doctree parsed from MyST.

v0.1.0
======

:Date: 2024-10-31 (JST)

Features
--------

* Implement feature as very simple approach.
* There are not configurations.
